@@ -18,9 +18,8 @@ fn parse_yaml(path: &Path) -> Result<TaskList, String> {
     let config = YamlLoader::load_from_str(&contents).unwrap();
 
     let entries = &config[0];
-
-    if entries["tasks"] == Yaml::BadValue {
-        return Err(String::from("no tasks found"));
+    if entries["tasks"] == Yaml::BadValue || entries["tasks"] == Yaml::Null {
+        return Err(String::from("\nERR: No tasks defined"));
     }
 
     let mut tasks: Vec<Task> = vec![];
@@ -106,6 +105,7 @@ mod test {
         let config = YamlConfig {};
         let result = config.read(src_path.to_str().unwrap());
 
-        assert!(result.unwrap_err().contains("no tasks found"));
+        assert!(result.is_err());
+        assert!(result.unwrap_err().contains("ERR: No tasks defined"));
     }
 }
